<template>
  <el-container>
    <el-main>
      <basic-container>
        <avue-crud v-model="form" ref="crud" :option="option" :data="data" @on-load="onLoad" :page.sync="page"
                   @search-change="searchChange"
                   @search-reset="searchReset"
                   @selection-change="selectionChange"
                   @current-change="currentChange"
                   @size-change="sizeChange"
                   @refresh-change="refreshChange" @row-click="rowClick">
          <template slot="menu" slot-scope="{row,index}">
            <el-button icon="el-icon-edit" size="small" type="text" @click="updateSave(row,index)">编辑</el-button>
            <el-button icon="el-icon-delete" size="small" type="text" @click="deleteSave(row,index)">删除</el-button>
            <el-button v-if="row.usedflag=='false'" icon="el-icon-position" size="small" type="text" @click="ENABLE(row,index)">启用</el-button>
            <el-button v-else icon="el-icon-finished" size="small" type="text" @click="DISABLE(row,index)">停用</el-button>
          </template>
          <template slot="menuLeft">
            <el-button size="small" type="primary" icon="el-icon-plus" @click="addSave">新&nbsp;&nbsp;增
            </el-button>
            <el-button size="small" icon="el-icon-share" @click="PUSH">同  步
            </el-button>
            <el-button size="small" icon="el-icon-search" @click="openAdvancedQuery">查  询
            </el-button>
          </template>
        </avue-crud>
      </basic-container>
    </el-main>
    <infoForm ref="infoForm" @refreshTable="refreshChange" :formData="editAttribute"></infoForm>
    <!-- 高级查询对话框 -->
    <advanced-query
      :ref="advancedQueryParam.ref"
      :options="advancedQueryParam.options"
      :visible.sync="advancedQueryParam.advancedQuerySettingBox"
      @echoContion="echoSeniorContionMap">
    </advanced-query>
  </el-container>
</template>

<script>
import {
  getList,add,edit,del,push,updateStatus
} from "@/api/docking/info";
import {getDictionary} from "@/api/omd/enum";
import infoForm from "./infoForm.vue";

export default {
  name: "info",
  components:{infoForm},
  data() {
    return {
      page: {
        pageSize: 10,
        currentPage: 1,
        total: 100
      },
      selectRow: "",
      data: [],
      form: {},
      attribute: {
        nullable: true
      },
      editAttribute: {},
      applyRangeData: [],
      selectionList: [],
      option: {
        height: "auto",
        calcHeight: 20,
        tip: false,
        headerAlign: "center",
        border: true,
        index: true,
        selection: true,
        searchShow: false,
        searchMenuSpan: 6,
        rowKey: "id",
        tabs: true,
        stripe: true,
        indexFixed: false,
        menuWidth: 180,
        highlightCurrentRow: true,
        addBtn: false,
        editBtn: false,
        delBtn: false,
        columnBtn: false,
        column: [{
          label: '推送类型',
          field: 'pushTypeText',
          sortable: true,
          width: 150,
          type: 'select',
          dicData: this.pushType,
          props: {
            label: "value",
            value: "key"
          },
        }, {
          label: '系统名称',
          prop: 'sysbasename',
          sortable: true,
          search: true,
          width: 150
        }, {
          label: '系统编号',
          prop: 'sysbaseid',
          sortable: true,
          search: true,
          width: 150
        }, {
          label: '接口函数',
          prop: 'interfaceFunction',
          sortable: true,
          width: 150
        }, {
          label: '命名空间',
          prop: 'namespace',
          sortable: true,
          width: 150
        }, {
          label: 'soapAction',
          prop: 'soapaction',
          sortable: true,
          width: 150
        }, {
          label: '参数名称',
          prop: 'targName',
          sortable: true,
          width: 150
        }, {
          label: '调用方式',
          prop: 'cxfaxis',
          sortable: true,
          width: 150
        }, {
          label: '请求地址',
          prop: 'requesturl',
          sortable: true,
          width: 150
        }, {
          label: '参数类型',
          prop: 'paramtype',
          sortable: true,
          width: 150
        }, {
          label: '返回值类型',
          prop: 'returntype',
          sortable: true,
          width: 150
        }]
      },
      itemForm: {
        itemData: {},
        activeName: "referTab",
        enumInitFlag: false,
        referInitFlag: false,
        form: {}
      },
      pushType: [{key: '1', value: '数据推送'},
        {key: '2', value: '分类推送'},
        {key: '3', value: '编码申请'},
        {key: '4', value: '编码更改（状态、回收）'},
        {key: '5', value: '分类查询'},
        {key: '6', value: '含规则信息的分类查询'},
        {key: '7', value: '数据查询'}],
      // 高级查询对话框相关参数
      advancedQueryParam: {
        ref: 'advancedQuery',
        advancedQuerySettingBox: false,
        options: [],
        currentOpen: '', //当前打开高级查询的窗口是
        //conditionMapParams: {},
      }
    };
  },
  created() {
  },
  computed: {
    oids() {
      let oids = [];
      this.selectionList.forEach(ele => {
        oids.push(ele.oid);
      });
      return oids.join(",");
    }
  },
  methods: {
    searchReset() {
      this.query = {};
      this.onLoad(this.page);
    },
    searchChange(params, done) {
      this.query = params;
      this.page.currentPage = 1;
      this.onLoad(this.page);
      done();
    },
    selectionChange(list) {
      this.selectionList = list;
      if(this.selectionList.length <= 0){
        this.itemForm.itemData = null
        this.selectRow = null
        this.attribute = null
      }
      if (this.selectionList.length > 0) {
        this.itemForm.itemData = this.selectionList[list.length-1];
        this.selectRow = this.selectionList[list.length-1].$index;
        this.attribute = this.selectionList[list.length-1];
      }
    },
    selectionClear() {
      this.selectionList = [];
      this.$refs.crud.toggleSelection();
    },
    currentChange(currentPage) {
      this.page.currentPage = currentPage;
    },
    sizeChange(pageSize) {
      this.page.pageSize = pageSize;
    },
    refreshChange() {
      this.onLoad(this.page, this.query);
    },
    addSave() {
      this.$refs.infoForm.showSubmitDialog = true;
      const newAttr = {};
      newAttr.nullable = true;
      this.$refs.infoForm.formData = newAttr;
    },
    updateSave(row,index) {
      this.selectRow = index;
      var json = JSON.stringify(row);
      this.editAttribute = JSON.parse(json);
      this.editAttribute.nullable = row.nullable == 'true' ? true : false;
      this.$refs.infoForm.attribute = this.editAttribute;
      this.$refs.infoForm.showSubmitDialog = true;
      this.checkUsingReferDict(row);
      this.$refs.infoForm.activeName = this.itemForm.activeName;
      this.$refs.infoForm.enumInitFlag = this.itemForm.enumInitFlag;
      this.$refs.infoForm.referInitFlag = this.itemForm.referInitFlag;
      // this.refreshChange()
    },
    deleteSave(row,index) {
      this.$confirm("删除元数据将无法被恢复, 是否继续?", "提示", {
        iconClass: 'el-icon-question',
        confirmButtonText: "确定",
        cancelButtonText: "取消",
        showClose: true,
        type: "warning"
      }).then(() => {
        remove(row.oid).then(res => {
          this.$message.success("删除成功");
          this.refreshChange();
        });
      });
    },
    ENABLE(row,index){
      //启用
      this.updateStatus("enable");
    },
    DISABLE(row,index){
      //停用
      this.updateStatus("disable");
    },
    updateStatus(able){
      var that = this;
      var paramTemp = {
        update:able,
        oid:this.selectRow.oid,
        ts:this.selectRow.ts
      };
      this.$confirm("是否要"+(able == "enbale" ? "启用" : (able == "disable" ? "停用": "发布")) +"这条数据？", {
        confirmButtonText: "确定",
        cancelButtonText: "取消",
        type: "warning"
      })
        .then(() => {
          return updateStatus(paramTemp);
        })
        .then(() => {
          this.onLoad(this.page);
          this.$message({
            type: "success",
            message:(able == "enbale" ? "启用成功" : (able == "disable" ? "停用成功": "发布成功"))
          });
          this.$refs.crud.toggleSelection();
        });
    },
    PUSH(){
      if (this.selectionList.length != 1) {
        this.$message.error('请选择一条数据')
        return false;
      }
      this.$confirm("是否要"+ (this.selectionList[0].pushType == "1" ? "推送数据" : "推送分类"), {
        confirmButtonText: "确定",
        cancelButtonText: "取消",
        type: "warning"
      })
        .then(() => {
          return push(this.oids.split(','));
        })
        .then(() => {
          this.onLoad(this.page);
          this.$message({
            type: "success",
            message: "操作成功!"
          });
          this.$refs.crud.toggleSelection();
        });
    },
    onLoad(page, params = {}) {
      this.loading = true;
      getList(this.page.currentPage, this.page.pageSize, Object.assign(params, this.query)).then(res => {
        const data = res.data.data;
        this.page.total = data.total;
        this.data = data.records;
        this.loading = false;
        this.data = res.data.data.records;
        this.itemData = this.data[0];
      });
    },
    rowClick(row) {
      this.itemForm.itemData = row;
      this.selectRow = row;
      this.attribute = row;

      this.$refs.crud.toggleSelection();
      this.$refs.crud.toggleRowSelection(row); //选中当前行
      //this.checkUsingReferDict(row);
    },
    checkUsingReferDict(row){
      if (row.referToId !== null && row.referToId !== ""){
        this.itemForm.activeName = 'referTab';
        this.itemForm.referInitFlag = true;
        this.itemForm.enumInitFlag = false;
      }else if (row.usingDict === 'true'){
        this.itemForm.activeName = 'enumTab';
        this.itemForm.referInitFlag = false;
        this.itemForm.enumInitFlag = true;
        getDictionary({code: row.dictCode}).then(res => {
          this.editAttribute.dictValue = res.data.data[0].label;
          this.itemForm.itemData.dictValue = this.editAttribute.dictValue;
          this.$refs.infoForm.dictEnums = res.data.data;
        })
      }else {
        this.itemForm.activeName = 'referTab';
        this.itemForm.referInitFlag = true;
        this.itemForm.enumInitFlag = false;
      }
    },
    selectBtmType() {
      this.referType.display = true;
      this.referType.title = "请选择" + this.referType.value;
    },
    applyRangeOpen() {
      if (!this.selectRow && this.selectRow != 0) {
        this.$message({
          type: "warning",
          message: "请先选择属性"
        });
      }
      var oid = this.data[this.selectRow].oid;
      getApplyRange(oid).then(res => {
        this.applyRangeData = res.data.data;
        this.$refs.applyRange.rangeData = this.applyRangeData;
        this.$refs.applyRange.showDialog = true;

      });
    },
    /** 高级查询对话框组件,组件返回的值是condtionMap[field]形式的查询条件，保留了和之前一样的方式 */
    echoSeniorContionMap(conditionMaps){
      if(JSON.stringify(conditionMaps)!='{}'){
        this.query = conditionMaps;
        this.onLoad(this.page);
      }
    },
    openAdvancedQuery(){
        this.advancedQueryParam.options = [
          {
            data: [],
            title: '编号',
            fieldType: 'text',
            queryField: 'id',
          },{
            data: [],
            title: '名称',
            fieldType: 'text',
            queryField: 'name',
          },{
            data: [],
            title: '描述',
            fieldType: 'text',
            queryField: 'description',
          },{
            data: [
              // {
              //   key: '编辑中',
              //   value: 'Editing',
              // },
              // {
              //   key: '已发布',
              //   value: 'Released',
              // },
              // {
              //   key: '停用',
              //   value: 'Disabled',
              // },
            ],
            title: '状态',
            fieldType: 'combox',
            queryField: 'lcStatus',
            comboxKey: 'codeSearchLCStatus',
          },
        ]

      this.advancedQueryParam.currentOpen = 'info';
      this.advancedQueryParam.advancedQuerySettingBox = true;
    },
  }
}
</script>

<style lang="scss">
.applyRangeTable>.el-card:nth-of-type(2)>.el-card__body>.avue-crud__menu {
  display: none !important;
}
</style>
